@@ -8,7 +8,8 @@ def GetJsonFromFile(jsonPath):
     f.close()
     return result
 
-def ConvertJsonToDocumentsObjects(json):
+def ConvertJsonToDocumentsObjects(jsonPath):
+    json = GetJsonFromFile(jsonPath)
     listOfDocuments = []
     for i in json:
         index = i["Index"]
